/*\
 * MICE Column List View
 * Version 1.02
 * Copyright (C) 2000-2005 Colin Munro
 *
 * ListViewerTypes.h - definitions of utility objects
 *
 * Please see license.txt and readme.txt for more information on this product. If
 * you use it in a non-freeware product, a one-off payment of $15 is required
 * to license it for your software.
 *
 * This file contains utility classes for standard field and column types. You
 * can override these (e.g. CTitledColumn) to create your own columns, or
 * override the ones in ListViewer.h for completely different column types
 * (e.g. columns with bitmap titles and fields)
\*/

#ifndef __LISTVIEWERTYPES_H__
#define __LISTVIEWERTYPES_H__

#include "ListViewer.h"

// Class to draw a string title at the top of a column
class CTitledColumn : public CColumn
{
public:
	CTitledColumn(const char *title,float width,float minWidth,float maxWidth);
	~CTitledColumn();

	virtual void DrawTitle(BView *targetView,BRect rect,seltype selected,bool bTransparent=false);

	void SetString(char *title);
	const char* GetString(void);
private:
	char *title;
};

// Class to draw a bitmap title at the top of a column
class CBitmapColumn : public CColumn
{
public:
	CBitmapColumn(BBitmap *title,float width,float minWidth,float maxWidth);
	~CBitmapColumn();
	
	virtual void DrawTitle(BView *targetView,BRect rect,seltype selected,bool bTransparent=false);
	
	void SetBitmap(BBitmap *title);
	BBitmap* GetBitmap(void);
private:
	BBitmap *title;
};

// Classes for drawing a string-based column
class CStringColumn;

class CStringField : public CField
{
public:
	CStringField(char *string);
	~CStringField();
	
	void SetColour(rgb_color colour);
	rgb_color Colour(void) const;
	
	void SetString(char *string);
	char* String(void) const;
	
	bool Bold(void);				// Is text bold?
	void SetBold(bool bBold=true);	// Make it so
private:
	friend CStringColumn;
	char *string;
	rgb_color colour;
	bool bBold;
	
	/*
	void TryResize(float width);
	float oldwidth;
	char *viewstr;
	*/
};

class CStringColumn : public CTitledColumn
{
public:
	CStringColumn(const char *title,float width,float minWidth,float maxWidth);
	
	virtual void DrawField(BView *targetView,BRect rect,CField *rowdata,bool bSelected,rgb_color highlight);
	virtual int CompareFields(CField *row1,CField *row2);
};

// Classes for drawing an integer-based column
class CIntColumn;

class CIntField : public CField
{
public:
	CIntField(int i);
	
	void SetInteger(int i);
	int Integer(void) const;
private:
	friend CIntColumn;
	int i;
};

class CIntColumn : public CTitledColumn
{
public:
	CIntColumn(const char *title,float width,float minWidth,float maxWidth);
	
	virtual void DrawField(BView *targetView,BRect rect,CField *rowdata,bool bSelected,rgb_color highlight);
	virtual int CompareFields(CField *row1,CField *row2);
};

// Classes for drawing a date-based column
class CDateColumn;

class CDateField : public CField
{
public:
	CDateField(uint32 time);
	~CDateField();
	
	void SetTime(uint32 time);
	uint32 Time(void) const;
protected:
	virtual char* MakeDateString(time_t time);
private:
	friend CDateColumn;
	uint32 fieldtime;
	
	char *string;
};

class CDateColumn : public CTitledColumn
{
public:
	CDateColumn(const char *title,float width,float minWidth,float maxWidth);
	
	virtual void DrawField(BView *targetView,BRect rect,CField *rowdata,bool bSelected,rgb_color highlight);
	virtual int CompareFields(CField *row1,CField *row2);
};

// Classes for a bitmap-based column
class CBitmapListColumn;

class CBitmapField : public CField
{
public:
	CBitmapField(BBitmap *title,int level=0,bool bVisible=true);
	~CBitmapField();
	
	void SetBitmap(BBitmap *title);
	BBitmap* GetBitmap(void);
	
	void SetLevel(int level);
	int GetLevel(void);
	
	void SetVisible(bool bVisible);
	bool IsVisible(void);
private:
	friend CBitmapListColumn;
	BBitmap *bitmap;
	int value;
	bool bVisible;
};

class CBitmapListColumn : public CBitmapColumn
{
public:
	CBitmapListColumn(BBitmap *title,float width,float minWidth,float maxWidth);
	
	virtual void DrawField(BView *targetView,BRect rect,CField *rowdata,bool bSelected,rgb_color highlight);
	virtual int CompareFields(CField *row1,CField *row2);
};

#endif // __LISTVIEWERTYPES_H__
